@@ -16,4 +16,9 @@ def add_config(_C):
     # ---------------------------------------------------------------------------- #
     _C.DATASET = CN()
     _C.DATASET.NAME = 'CIFAR100'
-    _C.DATASET.DATA_DIR = './data/cifar'
+    # train data path
+    _C.DATASET.TRAIN_ROOT = './data/cifar'
+    # test data path
+    _C.DATASET.TEST_ROOT = './data/cifar'
+    # used for evaluator
+    _C.DATASET.TOP_K = (1,)
